OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Forespørgslen mislykkedes, netværksforbindelse er ikke tilgængelig!",
    "Request unauthorized. Are you logged in?" : "Forespørgslen var ikke autoriseret. Er du logget ind?",
    "Request forbidden. Are you an admin?" : "Forespørgslen er ikke tilladt. Er du administrator?",
    "Token expired or app not enabled! Reload the page!" : "Nøglen er udløbet  eller appen er ikke aktiveret! Genindlæs siden!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Intern server fejl! Tjek din data/nextcloud.log log-fil for yderligere information.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Forespørgslen mislykkedes, Nextcloud er i øjeblikket i vedligeholdelse tilstand!",
    "News" : "Nyheder",
    "Use system cron for updates" : "Benyt system cron til opdateringer",
    "Purge interval" : "Oprydningsinterval",
    "Maximum read count per feed" : "Det maksimale antal læsninger per feed",
    "Maximum redirects" : "Maksimum for videredirigeringer",
    "Feed fetcher timeout" : "Tidsudløb for feed-indhenter",
    "Explore Service URL" : "Udforsk tjenestens URL",
    "Saved" : "Gemt",
    "Download" : "Download",
    "Close" : "Luk",
    "No articles available" : "Ingen tilgængelige artikler",
    "No unread articles available" : "Ingen tilgængelige ulæste artikler",
    "Open website" : "Åbn websted",
    "Star article" : "Stjernemarkér artiklen",
    "Unstar article" : "Fjern stjerne fra artiklen",
    "Keep article unread" : "Bevar artikel ulæst",
    "Remove keep article unread" : "Fjern \"bevar artikel ulæst\"",
    "by" : "af",
    "from" : "fra",
    "Play audio" : "Afspil lydfil",
    "Download audio" : "Hent lydfil",
    "Download video" : "Hent video",
    "Keyboard shortcut" : "Tastaturgenvej",
    "Description" : "Beskrivelse",
    "right" : "højre",
    "Jump to next article" : "Gå til næste artikel",
    "left" : "venstre",
    "Jump to previous article" : "Gå til forrige artikel",
    "Toggle star article" : "Slå stjerne for artikel til/fra",
    "Star article and jump to next one" : "Stjernemarkér artikel og få til den næste",
    "Toggle keep current article unread" : "Slå \"bevar nuværende artikel ulæst\" til/fra",
    "Open article in new tab" : "Åbn artikel i en ny fane",
    "Toggle expand article in compact view" : "Slå \"udvid artikel i kompakt visning\" til/fra",
    "Refresh" : "Opdatér",
    "Load next feed" : "Indlæs næste feed",
    "Load previous feed" : "Indlæs forrige feed",
    "Load next folder" : "Indlæs næste mappe",
    "Load previous folder" : "Indlæs forrige mappe",
    "Scroll to active navigation entry" : "Rul frem til aktive navigationspost",
    "Focus search field" : "Fokuser søgefelt",
    "Mark current article's feed/folder read" : "Markér nuværende artikels feed/mappe som læst",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eller webcron tilstand opdaget! Dine feed vil ikke blive opdateret!",
    "How to set up the operating system cron" : "Sådan opsætter du cron i operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installere og oprette en hurtigere parallel opdateringsprogram, der bruger Nyheds app's opdateringsAPI",
    "Subscribe" : "Abonner",
    "Web address" : "Web adresse",
    "Feed exists already!" : "Feedet findes allerede!",
    "Folder" : "Mappe",
    "No folder" : "Ingen Mappe",
    "New folder" : "Ny mappe",
    "Folder name" : "Mappenavn",
    "Go back" : "Gå tilbage",
    "Folder exists already!" : "Mappen findes allerede!",
    "Credentials" : "Brugeroplysninger",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundlæggende HTTP Autentificerings akkreditiver skal lagres ukrypteret! Alle med adgang til server eller database vil være i stand til at få adgang til dem!",
    "Username" : "Brugernavn",
    "Password" : "Adgangskode",
    "New Folder" : "Ny mappe",
    "Create" : "Ny",
    "Explore" : "Udforsk",
    "Update failed more than 50 times" : "Opdatering mislykkedes mere end 50 gange",
    "Deleted feed" : "Slet feed",
    "Undo delete feed" : "Fortryd sletning af feed",
    "Rename" : "Omdøb",
    "Menu" : "Menu",
    "Mark read" : "Marker som læst",
    "Unpin from top" : "Frigør fra toppen",
    "Pin to top" : "Fastgør til toppen",
    "Newest first" : "Nyeste først",
    "Oldest first" : "Ældste først",
    "Default order" : "Standard rækkefølge",
    "Enable full text" : "Slå fuld tekst til",
    "Disable full text" : "Slå fuld tekst fra",
    "Unread updated" : "Ulæste opdateret",
    "Ignore updated" : "Ignorér updaterede",
    "Open feed URL" : "Åbn feed URL",
    "Delete" : "Slet",
    "Dismiss" : "Afvis",
    "Collapse" : "Sammenfold",
    "Deleted folder" : "Slettede mappen",
    "Undo delete folder" : "Fortryd sletning af mappe",
    "Starred" : "Stjernemarkéret",
    "Unread articles" : "Ulæste artikler",
    "All articles" : "Alle artikler",
    "Settings" : "Indstillinger",
    "Disable mark read through scrolling" : "Slå markér som læst fra når der rulles",
    "Compact view" : "Kompakt visning",
    "Expand articles on key navigation" : "Udvid artikler ved tastenavigation",
    "Show all articles" : "Vis alle artikler",
    "Reverse ordering (oldest on top)" : "Vend om på rækkefølgen (ældste øverst)",
    "Subscriptions (OPML)" : "Abonnementer (OPML)",
    "Import" : "Importer",
    "Export" : "Eksportér",
    "Error when importing: File does not contain valid OPML" : "Fejl under importering: Fil indeholder ikke valid OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Fejl ved import: OPML indeholder hverken feeds eller mapper",
    "Unread/Starred Articles" : "Ulæste/stjernemarkerede artikler",
    "Error when importing: file does not contain valid JSON" : "Fejl ved import: filen indeholder ikke gyldig JSON kode",
    "Help" : "Hjælp",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Documentation" : "Dokumentation",
    "Report a bug" : "Rapporter en fejl"
},
"nplurals=2; plural=(n != 1);");
